package dk.eobjects.metamodel;

import dk.eobjects.metamodel.data.DataSet;
import dk.eobjects.metamodel.query.Query;
import dk.eobjects.metamodel.schema.Schema;

/**
 * Defines a strategy to use for metadata and data access.
 */
public interface IDataContextStrategy {

	/**
	 * @return the name of the default schema provided by this strategy or null
	 *         if none is present or possible to deterministically tell.
	 */
	public String getDefaultSchemaName() throws MetaModelException;

	/**
	 * Executes a query.
	 * 
	 * @param query
	 * @return a dataset representing the result of the query.
	 */
	public DataSet executeQuery(Query query) throws MetaModelException;

	/**
	 * @return an array of schema names within this datastore.
	 */
	public String[] getSchemaNames() throws MetaModelException;

	/**
	 * @param name
	 * @return the schema with the specified name, or null if such a schema is
	 *         not available
	 */
	public Schema getSchemaByName(String name) throws MetaModelException;

}
