/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.data;

import java.util.ArrayList;
import java.util.List;

import javax.swing.table.AbstractTableModel;

import dk.eobjects.metamodel.query.SelectItem;

/**
 * TableModel specialized for getting data from a DataSet
 */
class DataSetTableModel extends AbstractTableModel {

	private static final long serialVersionUID = 267644807447629777L;
	private List<Row> _materializedRows = new ArrayList<Row>();
	private DataSet _dataSet;
	private SelectItem[] _selectItems;

	public DataSetTableModel(DataSet dataSet) {
		_dataSet = dataSet;
		_selectItems = dataSet.getSelectItems();
	}

	public int getColumnCount() {
		return _selectItems.length;
	}

	public int getRowCount() {
		materialize();
		return _materializedRows.size();
	}

	private void materialize() {
		if (_dataSet != null) {
			while (_dataSet.next()) {
				_materializedRows.add(_dataSet.getRow());
			}
			_dataSet.close();
			_dataSet = null;
		}
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		materialize();
		return _materializedRows.get(rowIndex).getValue(columnIndex);
	}

	@Override
	public String getColumnName(int column) {
		return _selectItems[column].getSuperQueryAlias(false);
	}

	@Override
	public void setValueAt(Object value, int rowIndex, int columnIndex) {
		throw new UnsupportedOperationException(
				"DataSetTableModels are immutable, so setValueAt() method is unsupported.");
	}
}
