/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.data;

import java.util.ArrayList;
import java.util.List;

import dk.eobjects.metamodel.MetaModelException;
import dk.eobjects.metamodel.query.SelectItem;

class InMemoryDataSetStrategy implements IDataSetStrategy {

	private SelectItem[] _selectItems;
	private List<Object[]> _data;
	private int _rowNumber = -1;

	/**
	 * Creates a new in-memory implementation of IDataSetStrategy
	 * 
	 * @param selectItems
	 * @param data
	 * @param maxRows
	 */
	public InMemoryDataSetStrategy(SelectItem[] selectItems,
			List<Object[]> data, Integer maxRows) {
		_selectItems = selectItems;
		_data = data;
	}

	public InMemoryDataSetStrategy(List<Row> rows) {
		_data = new ArrayList<Object[]>();
		if (rows.size() > 0) {
			_selectItems = rows.get(0).getSelectItems();
			for (Row row : rows) {
				_data.add(row.getValues());
			}
		} else {
			_selectItems = new SelectItem[0];
		}
	}

	public void close() {
	}

	public Row getRow() throws MetaModelException {
		if (_rowNumber < 0 || _rowNumber >= _data.size()) {
			throw new MetaModelException("No such row number: " + _rowNumber);
		}
		Row row = new Row(_selectItems, _data.get(_rowNumber));
		return row;
	}

	public boolean next() {
		_rowNumber++;
		if (_rowNumber < _data.size()) {
			return true;
		}
		return false;
	}

	public SelectItem[] getSelectItems() {
		return _selectItems;
	}

}
