/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.data;

import dk.eobjects.metamodel.MetaModelException;
import dk.eobjects.metamodel.query.SelectItem;

/**
 * Wraps another DataSet and simply adds a maximum number of rows constraint
 */
public class MaxRowsDataSetStrategyWrapper implements IDataSetStrategy {

	private DataSet _dataSet;
	private int _rowsLeft;

	public MaxRowsDataSetStrategyWrapper(DataSet dataSet, int maxRows) {
		_dataSet = dataSet;
		_rowsLeft = maxRows;
	}

	public void close() {
		_dataSet.close();
	}

	public Row getRow() throws MetaModelException {
		return _dataSet.getRow();
	}

	public SelectItem[] getSelectItems() {
		return _dataSet.getSelectItems();
	}

	public boolean next() {
		if (_rowsLeft > 0) {
			boolean next = _dataSet.next();
			if (next) {
				_rowsLeft--;
			}
			return next;
		}
		return false;
	}

}
