/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.data;

import dk.eobjects.metamodel.MetaModelException;
import dk.eobjects.metamodel.query.SelectItem;

public class RowFilterDataSetStrategyWrapper implements IDataSetStrategy {

	private DataSet _dataSet;
	private IRowFilter[] _filters;
	private Row _row;

	public RowFilterDataSetStrategyWrapper(DataSet dataSet,
			IRowFilter... filters) {
		_dataSet = dataSet;
		_filters = filters;
	}

	public void close() {
		_dataSet.close();
	}

	public Row getRow() throws MetaModelException {
		return _row;
	}

	public SelectItem[] getSelectItems() {
		return _dataSet.getSelectItems();
	}

	public boolean next() {
		boolean next = false;
		while (_dataSet.next()) {
			Row row = _dataSet.getRow();
			for (IRowFilter filter : _filters) {
				next = filter.accept(row);
				if (!next) {
					break;
				}
			}
			if (next) {
				_row = row;
				break;
			}
		}
		return next;
	}

}
