/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.query;

/**
 * Defines the types of operators that can be used in filters.
 * 
 * @see FilterItem
 */
public enum OperatorType {

	EQUALS_TO, DIFFERENT_FROM, LIKE, HIGHER_THAN, LOWER_THAN;

/**
	 * Converts from SQL string literals to an OperatorType. Valid SQL values
	 * are "=", "<>", "LIKE", ">" and "<".
	 * 
	 * @param sqlType
	 * @return
	 */
	public static OperatorType convertOperatorType(String sqlType) {
		if (sqlType != null) {
			if ("=".equals(sqlType)) {
				return EQUALS_TO;
			}
			if ("<>".equals(sqlType)) {
				return DIFFERENT_FROM;
			}
			if ("LIKE".equalsIgnoreCase(sqlType)) {
				return LIKE;
			}
			if (">".equals(sqlType)) {
				return HIGHER_THAN;
			}
			if ("<".equals(sqlType)) {
				return LOWER_THAN;
			}
		}
		return null;
	}
}
