/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.query;

import dk.eobjects.metamodel.schema.Column;

/**
 * Represents the SELECT clause of a query containing SelectItems.
 * 
 * @see SelectItem
 */
public class SelectClause extends QueryClause<SelectItem> {

	private static final long serialVersionUID = -2458447191169901181L;
	private boolean _distinct = false;

	public SelectClause(Query query) {
		super(query, QueryClause.PREFIX_SELECT, QueryClause.DELIM_COMMA);
	}

	public SelectItem getSelectItem(Column column) {
		if (column != null) {
			for (SelectItem item : getItems()) {
				if (column.equals(item.getColumn())) {
					return item;
				}
			}
		}
		return null;
	}

	@Override
	public String toString() {
		if (getItems().size() == 0) {
			return "";
		}

		StringBuilder sb = new StringBuilder(super.toString());
		if (_distinct) {
			sb.insert(QueryClause.PREFIX_SELECT.length(), "DISTINCT ");
		}
		return sb.toString();
	}

	public boolean isDistinct() {
		return _distinct;
	}

	public void setDistinct(boolean distinct) {
		_distinct = distinct;
	}

	@Override
	public boolean equals(Object obj) {
		boolean equals = super.equals(obj);
		if (equals) {
			SelectClause that = (SelectClause) obj;
			equals = this.isDistinct() && that.isDistinct();
		}
		return equals;
	}
}
