package dk.eobjects.metamodel.util;

import java.util.Comparator;

import org.apache.commons.math.MathException;
import org.apache.commons.math.util.DefaultTransformer;

public class BooleanComparator implements Comparator<Object> {

	private static BooleanComparator _instance = new BooleanComparator();

	private BooleanComparator() {
	}

	public static Comparator<Object> getComparator() {
		return _instance;
	}

	public static Comparable<Object> getComparable(Object object) {
		final Boolean b = toBoolean(object);
		return new Comparable<Object>() {

			public int compareTo(Object o) {
				return _instance.compare(b, o);
			}

			@Override
			public String toString() {
				return "BooleanComparable[boolean=" + b + "]";
			}
		};
	}

	public int compare(Object o1, Object o2) {
		Boolean b1 = toBoolean(o1);
		Boolean b2 = toBoolean(o2);
		return b1.compareTo(b2);
	}

	private static Boolean toBoolean(Object o) {
		if (o != null) {
			if (o instanceof Boolean) {
				return (Boolean) o;
			}
			if (o instanceof String) {
				String s = (String) o;
				s = s.trim();
				if ("true".equalsIgnoreCase(s) || "1".equals(s)
						|| "y".equalsIgnoreCase(s) || "yes".equalsIgnoreCase(s)) {
					return true;
				}
			}
			if (o instanceof Number) {
				try {
					double number = new DefaultTransformer().transform(o);
					if (number >= 1.0) {
						return true;
					}
				} catch (MathException e) {
				}
			}
		}
		return false;
	}

}
