/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Various helper methods for handling files
 */
public class FileHelper {

	private static final Log _log = LogFactory.getLog(FileHelper.class);

	public static final String ENCODING = "UTF-8";

	public static File getTempDir() {
		File result = null;
		String tmpDirPath = System.getenv("java.io.tmpdir");
		if (tmpDirPath != null && !"".equals(tmpDirPath)) {
			result = new File(tmpDirPath);
		} else {
			_log
					.warn("Could not determine tmpdir by using environment variable.");
			try {
				File file = File.createTempFile("foo", "bar");
				result = file.getParentFile();
				file.delete();
			} catch (IOException e) {
				_log.error(e);
				result = new File("metamodel.tmp.dir");
				result.mkdir();
				result.deleteOnExit();
			}
			_log.warn("Using '" + result.getAbsolutePath() + "' as tmpdir.");
		}
		return result;
	}

	public static BufferedWriter getBufferedWriter(File file) {
		return new BufferedWriter(getWriter(file));
	}

	public static Writer getWriter(File file) {
		try {
			return new OutputStreamWriter(new FileOutputStream(file), ENCODING);
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

	public static void writeStringAsFile(File file, String string) {
		try {
			BufferedWriter bw = getBufferedWriter(file);
			bw.write(string);
			bw.close();
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

	public static BufferedReader getBufferedReader(File file) {
		return new BufferedReader(getReader(file));
	}

	public static Reader getReader(File file) {
		try {
			FileInputStream inputStream = new FileInputStream(file);
			InputStreamReader inputStreamReader = new InputStreamReader(
					inputStream, ENCODING);
			return inputStreamReader;
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

	public static String readFileAsString(File file) {
		try {
			BufferedReader br = getBufferedReader(file);
			StringBuilder sb = new StringBuilder();
			boolean firstLine = true;
			for (String line = br.readLine(); line != null; line = br
					.readLine()) {
				if (firstLine) {
					firstLine = false;
				} else {
					sb.append('\n');
				}
				sb.append(line);
			}
			br.close();
			return sb.toString();
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}
}
