/*
 * Copyright 2008 eobjects.dk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dk.eobjects.metamodel.util;

import java.util.Comparator;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.math.MathException;
import org.apache.commons.math.util.DefaultTransformer;

/**
 * Comparator that can compare numbers of various kinds (short, integer, float,
 * double etc)
 */
public class NumberComparator implements Comparator<Object> {

	private static final Log _log = LogFactory.getLog(NumberComparator.class);
	private static Comparator<Object> _instance = new NumberComparator();

	public static Comparator<Object> getComparator() {
		return _instance;
	}

	private NumberComparator() {
	}

	public static Comparable<Object> getComparable(Object o) {
		try {
			final double n = new DefaultTransformer().transform(o);
			return new Comparable<Object>() {

				public int compareTo(Object o) {
					return _instance.compare(n, o);
				}

				@Override
				public String toString() {
					return "NumberComparable[number=" + n + "]";
				}

			};
		} catch (MathException e) {
			_log.error(e);
			throw new RuntimeException(e);
		}
	}

	public int compare(Object o1, Object o2) {
		try {
			double n1 = new DefaultTransformer().transform(o1);
			double n2 = new DefaultTransformer().transform(o2);
			return new Double(n1).compareTo(n2);
		} catch (MathException e) {
			_log.error(e);
			throw new RuntimeException(e);
		}
	}
}
